@@ -23,7 +23,7 @@
 #ifndef LOGINSETTINGS_H
 #define LOGINSETTINGS_H
 
-#include "account.h"
+#include "account/accountManager.h"
 #include "twitterapplicationitem.h"
 #include "applicationItems/twitterbutton.h"
 #include "applicationItems/twittercheckbox.h"
