@@ -30,6 +30,7 @@ UserInfo::UserInfo() :
         screenName(QString()),
         location(QString()),
         description(QString()),
+        imageUrl(QString()),
         homepage(QString()),
         hasHomepage(false),
         profileProtected(false),
@@ -39,9 +40,25 @@ UserInfo::UserInfo() :
         statusesCount(-1),
         favouritesCount(-1),
         verified(false)
-{
-}
+{}
 
+UserInfo::UserInfo(UserInfo *other) :
+        id( other->id ),
+        name( other->name),
+    screenName( other->screenName ),
+    location( other->location ),
+    description( other->description ),
+    imageUrl( other->imageUrl ),
+    homepage( other->homepage ),
+    hasHomepage( other->hasHomepage ),
+    profileProtected( other->profileProtected ),
+    followersCount( other->followersCount ),
+    friendsCount( other->friendsCount ),
+    utcOffset( other->utcOffset ),
+    statusesCount( other->statusesCount ),
+    favouritesCount( other->favouritesCount ),
+    verified( other->verified )
+{}
 
 void UserInfo::initialize()
 {
@@ -120,3 +137,23 @@ QDataStream& operator>>( QDataStream & in, UserInfo &userInfo )
     in >> userInfo.verified;
     return in;
 }
+
+bool UserInfo::operator ==(const UserInfo &other)
+{
+    return ( id == other.id
+            && name == other.name
+            && screenName == other.screenName
+            && location == other.location
+            && description == other.description
+            && imageUrl == other.imageUrl
+            && homepage == other.homepage
+            && hasHomepage == other.hasHomepage
+            && profileProtected == other.profileProtected
+            && followersCount == other.followersCount
+            && friendsCount == other.friendsCount
+            && utcOffset == other.utcOffset
+            && statusesCount == other.statusesCount
+            && favouritesCount == other.favouritesCount
+            && verified == other.verified );
+
+}
